@@ -10,19 +10,21 @@
 
     .. autofunction:: node_text_transform
 
-    .. autofunction:: transform_curly_bracket_strip
-
     .. autofunction:: transform_url_command
 """
 
 import docutils.nodes
 import docutils.transforms
+import sphinx.util
 
 from pybtex.plugin import find_plugin
 
 from sphinxcontrib.bibtex.nodes import bibliography
 
 
+logger = sphinx.util.logging.getLogger(__name__)
+
+
 def node_text_transform(node, transform):
     """Apply transformation to all Text nodes within node."""
     for child in node.children:
@@ -32,16 +34,6 @@ def node_text_transform(node, transform):
             node_text_transform(child, transform)
 
 
-def transform_curly_bracket_strip(textnode):
-    """Strip curly brackets from text."""
-    text = textnode.astext()
-    if '{' in text or '}' in text:
-        text = text.replace('{', '').replace('}', '')
-        return docutils.nodes.Text(text)
-    else:
-        return textnode
-
-
 def transform_url_command(textnode):
     """Convert '\\\\url{...}' into a proper docutils hyperlink."""
     text = textnode.astext()
@@ -84,7 +76,7 @@ class BibliographyTransform(docutils.transforms.Transform):
             bibcache = env.bibtex_cache.get_bibliography_cache(
                 docname=docname, id_=id_)
             entries = env.bibtex_cache.get_bibliography_entries(
-                docname=docname, id_=id_, warn=env.app.warn)
+                docname=docname, id_=id_, warn=logger.warning)
             # locate and instantiate style and backend plugins
             style = find_plugin('pybtex.style.formatting', bibcache.style)()
             backend = find_plugin('pybtex.backends', 'docutils')()
@@ -117,10 +109,6 @@ class BibliographyTransform(docutils.transforms.Transform):
                     key = citation[0].astext()
                     bibcache.labels[key] = bibcache.labelprefix + entry.label
                 node_text_transform(citation, transform_url_command)
-                if bibcache.curly_bracket_strip:
-                    node_text_transform(
-                        citation,
-                        transform_curly_bracket_strip)
                 nodes += citation
                 if bibcache.list_ == "enumerated":
                     env.bibtex_cache.inc_enum_count(env.docname)
